@@ -129,11 +129,36 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAITranscription(self, request):
+        """查询AI转录任务状态。
+
+        :param request: Request instance for DescribeAITranscription.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeAITranscriptionRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeAITranscriptionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAITranscription", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAITranscriptionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeCallDetailInfo(self, request):
-        """查询指定时间内的用户列表及用户通话质量数据，可查询14天内数据。DataType 不为null，查询起止时间不超过1个小时，查询用户不超过6个，支持跨天查询。DataType为null时，查询起止时间不超过4个小时， 默认查询6个用户，同时支持每页查询100以内用户个数（PageSize不超过100）。接口用于查询质量问题，不推荐作为计费使用。（同老接口DescribeCallDetail）
+        """查询指定时间内的用户列表及用户通话质量数据，最大可查询14天内数据。DataType 不为null，查询起止时间不超过1个小时，查询用户不超过6个，支持跨天查询。DataType为null时，查询起止时间不超过4个小时， 默认查询6个用户，同时支持每页查询100以内用户个数（PageSize不超过100）。接口用于查询质量问题，不推荐作为计费使用。（同老接口DescribeCallDetail）
         **注意**：
         1.该接口只用于历史数据统计或核对数据使用，实时类关键业务逻辑不能使用。
-        2.该接口自2024年4月1日起正式商业化，可通过订阅[包月套餐](https://cloud.tencent.com/document/product/647/85386)「尊享版」和「旗舰版」或订阅[监控仪表盘](https://cloud.tencent.com/document/product/647/81331)商业套餐包解锁接口调用能力，[前往购买](https://buy.cloud.tencent.com/trtc)。
+        2.该接口自2024年4月1日起正式商业化，需订阅套餐解锁调用能力，提供以下两种解锁方式，可任选其一解锁：
+        方式一：通过订阅[包月套餐](https://cloud.tencent.com/document/product/647/85386)「尊享版」（可查近7天）和「旗舰版」（可查近14天），[前往订阅](https://buy.cloud.tencent.com/trtc?trtcversion=top)。
+        方式二：通过订阅[监控仪表盘](https://cloud.tencent.com/document/product/647/81331)商业套餐包「基础版」（可查近7天）和「进阶版」（可查近14天），[前往订阅](https://buy.cloud.tencent.com/trtc_monitor)。
 
         :param request: Request instance for DescribeCallDetailInfo.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeCallDetailInfoRequest`
@@ -315,10 +340,12 @@ class TrtcClient(AbstractClient):
 
 
     def DescribeRoomInfo(self, request):
-        """查询SdkAppId下的房间列表。默认返回10条通话，一次最多返回100条通话。可查询14天内的数据。（同老接口DescribeRoomInformation）
+        """查询SdkAppId下的房间列表。默认返回10条通话，一次最多返回100条通话。最大可查询14天内的数据。（同老接口DescribeRoomInformation）
         **注意**：
         1.该接口只用于历史数据统计或核对数据使用，实时类关键业务逻辑不能使用。
-        2.该接口自2024年4月1日起正式商业化，可通过订阅[包月套餐](https://cloud.tencent.com/document/product/647/85386)「尊享版」和「旗舰版」或订阅[监控仪表盘](https://cloud.tencent.com/document/product/647/81331)商业套餐包解锁接口调用能力，[前往购买](https://buy.cloud.tencent.com/trtc)。
+        2.该接口自2024年4月1日起正式商业化，需订阅套餐解锁调用能力，提供以下两种解锁方式，可任意其一解锁：
+        方式一：通过订阅[包月套餐](https://cloud.tencent.com/document/product/647/85386)「尊享版」（可查近7天）和「旗舰版」（可查近14天），[前往订阅](https://buy.cloud.tencent.com/trtc?trtcversion=top)。
+        方式二：通过订阅[监控仪表盘](https://cloud.tencent.com/document/product/647/81331)商业套餐包「基础版」（可查近7天）和「进阶版」（可查近14天），[前往订阅](https://buy.cloud.tencent.com/trtc_monitor)。
 
         :param request: Request instance for DescribeRoomInfo.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRoomInfoRequest`
@@ -753,10 +780,12 @@ class TrtcClient(AbstractClient):
 
 
     def DescribeUserInfo(self, request):
-        """查询指定时间内的用户列表，可查询14天内数据，查询起止时间不超过4小时。默认每页查询6个用户，支持每页最大查询100个用户PageSize不超过100）。（同老接口DescribeUserInformation）
+        """查询指定时间内的用户列表，最大可查询14天内数据，查询起止时间不超过4小时。默认每页查询6个用户，支持每页最大查询100个用户PageSize不超过100）。（同老接口DescribeUserInformation）
         **注意**：
         1.该接口只用于历史数据统计或核对数据使用，实时类关键业务逻辑不能使用。
-        2.该接口自2024年4月1日起正式商业化，可通过订阅[包月套餐](https://cloud.tencent.com/document/product/647/85386)「尊享版」和「旗舰版」或订阅[监控仪表盘](https://cloud.tencent.com/document/product/647/81331)商业套餐包解锁接口调用能力，[前往购买](https://buy.cloud.tencent.com/trtc)。
+        2.该接口自2024年4月1日起正式商业化，需订阅套餐解锁调用能力，提供以下两种解锁方式，可任选其一解锁：
+        方式一：通过订阅[包月套餐](https://cloud.tencent.com/document/product/647/85386)「尊享版」（可查近7天）和「旗舰版」（可查近14天），[前往订阅](https://buy.cloud.tencent.com/trtc?trtcversion=top)。
+        方式二：通过订阅[监控仪表盘](https://cloud.tencent.com/document/product/647/81331)商业套餐包「基础版」（可查近7天）和「进阶版」（可查近14天），[前往订阅](https://buy.cloud.tencent.com/trtc_monitor)。
 
         :param request: Request instance for DescribeUserInfo.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeUserInfoRequest`
@@ -939,6 +968,72 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def StartAITranscription(self, request):
+        """这个接口调用后，后台会启动转录机器人，实时进行语音识别并下发字幕和转录消息。
+        转录机器人支持两种拉流方式，通过TranscriptionMode字段控制：
+        - 拉取全房间的流。
+        - 拉取特定用户的流。
+
+        服务端实时下发字幕和会议记录有两种方式，通过IMAdminUserId和IMAdminUserSig字段控制：
+        - 如果填写IMAdminUserId和IMAdminUserSig，服务端会调用IM的[发送群组消息](https://cloud.tencent.com/document/product/269/1629)API来向端上实时下发消息。客户端只需监听群组消息的回调即可，比如[web端回调](https://cloud.tencent.com/document/product/269/75319)。
+        - 如果不填写IMAdminUserId和IMAdminUserSig，服务端使用TRTC自定义消息通道下发消息，CmdId固定是1。客户端只需监听自定义消息的回调即可，比如[c++回调](https://cloud.tencent.com/document/product/647/79637#4cd82f4edb24992a15a25187089e1565)。
+
+        服务端实时下发的消息是JSON字符串，实时字幕具体格式如下：
+        `{
+            "type": "subtitle",
+            "userid": "xxx",
+            "text": "xxx",
+            "translation_text": "xxx",
+            "start_time": "00:00:02",
+            "end_time": "00:00:05"
+        }`
+        字段作用如下：
+        - type是subtitle，表示这是实时字幕消息。
+        - userid表示是哪个用户说的话。
+        - text是语音识别出的文本。
+        - translation_text是text翻译后的文本，如果不启用翻译，则是空字符串。
+        - start_time和end_time表示该字幕消息从任务开启后的开始和结束时间。
+
+        转录消息具体格式如下：
+        `{
+            "type": "transcription",
+            "userid": "xxx",
+            "text": "xxx",
+            "translation_text": "xx",
+            "start_time": "00:00:02",
+            "end_time": "00:00:05"
+        }`
+        字段作用如下：
+        - type是transcription，表示这是转录消息。
+        - 其余字段同实时字幕消息。
+
+        转录消息和实时字幕消息的区别是，转录消息是完整的一句话，实时字幕消息则是这一句话的中间阶段。
+        假如有一句完整的话，“今天天气怎么样？”，那么服务的下发消息的顺序可能是这样：
+        - 字幕消息，“今天”
+        - 字幕消息，“今天天气”
+        - 字幕消息，“今天天气怎么样”
+        - 转录消息，“今天天气怎么样？”
+
+        :param request: Request instance for StartAITranscription.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.StartAITranscriptionRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.StartAITranscriptionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StartAITranscription", params, headers=headers)
+            response = json.loads(body)
+            model = models.StartAITranscriptionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def StartMCUMixTranscode(self, request):
         """接口说明：启动云端混流，并指定混流画面中各路画面的布局位置。
 
@@ -1192,6 +1287,29 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def StopAITranscription(self, request):
+        """停止AI转录任务。
+
+        :param request: Request instance for StopAITranscription.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.StopAITranscriptionRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.StopAITranscriptionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StopAITranscription", params, headers=headers)
+            response = json.loads(body)
+            model = models.StopAITranscriptionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def StopMCUMixTranscode(self, request):
         """接口说明：结束云端混流
 
@@ -1307,6 +1425,29 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def SummarizeTranscription(self, request):
+        """对转录的文本进行总结。
+
+        :param request: Request instance for SummarizeTranscription.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.SummarizeTranscriptionRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.SummarizeTranscriptionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SummarizeTranscription", params, headers=headers)
+            response = json.loads(body)
+            model = models.SummarizeTranscriptionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def UpdatePublishCdnStream(self, request):
         """更新转推任务。
         注：请参见启动转推任务的接口说明和使用说明。
